@@ -50,14 +50,15 @@ def Track(boxes, classes, confidence, frame):
         # cv2.rectangle(frame, (int(bbox[i][0]), int(bbox[i][1])), (int(bbox[i][2]), int(bbox[i][3])), (255, 255, 255), 2)
         cv2.putText(frame, "ID: " + str(track.track_id), (int(bbox[0]), int(bbox[1])), 0,
                     1.5e-3 * frame.shape[0], (0, 255, 0), 1)
-    """
-    for det in detections:
-        bbox = det.to_tlbr()
-        score = "%.2f" % round(det.confidence * 100, 2) + "%"
-        cv2.rectangle(frame, (int(bbox[0]), int(bbox[1])), (int(bbox[2]), int(bbox[3])), (255, 0, 0), 2)
-        if len(classes) > 0:
-            cls = det.cls
-            cv2.putText(frame, str(cls) + " " + score, (int(bbox[0]), int(bbox[3])), 0,
-                        1.5e-3 * frame.shape[0], (0, 255, 0), 1)
-    """
-    return frame
+
+    colors = np.random.uniform(0, 255, size=(len(classes), 3))
+
+    for i, label in enumerate(classes):
+
+        color = colors[classes.index(label)]
+
+        cv2.rectangle(frame, (bbox[i][0],bbox[i][1]), (bbox[i][2],bbox[i][3]), color, 2)
+
+        cv2.putText(frame, label, (bbox[i][0],bbox[i][1]-15), cv2.FONT_HERSHEY_SIMPLEX, 0.5, color, 2)
+
+    return frame
\ No newline at end of file
